#
# spec file for package perl-IPC-Run
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name IPC-Run
Name:           perl-IPC-Run
Version:        20231003.0.0
Release:        2.1
%define cpan_version 20231003.0
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        System() and background procs w/ piping, redirs, ptys (Unix, Win32)
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IO::Pty) >= 1.08
BuildRequires:  perl(Readonly::Array)
Requires:       perl(IO::Pty) >= 1.08
Provides:       perl(IPC::Run) = 20231003.0.0
Provides:       perl(IPC::Run::Debug) = 20231003.0.0
Provides:       perl(IPC::Run::IO) = 20231003.0.0
Provides:       perl(IPC::Run::Timer) = 20231003.0.0
Provides:       perl(IPC::Run::Win32Helper) = 20231003.0.0
Provides:       perl(IPC::Run::Win32IO) = 20231003.0.0
Provides:       perl(IPC::Run::Win32Process) = 20231003.0.0
Provides:       perl(IPC::Run::Win32Pump) = 20231003.0.0
%undefine       __perllib_provides
Recommends:     perl(IO::Pty) >= 1.08
Recommends:     perl(Readonly)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  netcfg libnss_usrfiles2
# MANUAL END

%description
IPC::Run allows you to run and interact with child processes using files,
pipes, and pseudo-ttys. Both system()-style and scripted usages are
supported and may be mixed. Likewise, functional and OO API styles are both
supported and may be mixed.

Various redirection operators reminiscent of those seen on common Unix and
DOS command lines are provided.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
# run.t sometimes fails with "Resource temporarily unavailable"
mv t/run.t t/run.tt
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changelog README.md
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Oct 11 2023 Tina Müller <tina.mueller@suse.com>
- Remove IPC-Run-0.89-path.diff (fixed upstream)
* Tue Oct  3 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20231003.0
  see /usr/share/doc/packages/perl-IPC-Run/Changelog
  20231003.0 Mon Oct 2 2023
  Windows now matches other platforms in that a child calling exit(N) causes
  result() to return N and full_result() to return N << 8.  On Windows, before
  this change, result() was returning N >> 8, and full_result() was returning N.
  Programs having workarounds for this may need to condition those workarounds on
  $IPC::Run::VERSION.
  - #157 - On Windows, avoid hang under IPCRUNDEBUG.
  - Refresh "cpanfile" from Makefile.PL, to allow use on Windows.
  - #163 - Normalize shebangs to /usr/bin/perl
  - Fix or skip all tests recently seen to fail on Windows.
  - Include t/result.t in releases.
  - #168 - Make full_result() and result() Windows behavior match non-Windows.
* Tue Aug 23 2022 Tina Müller <tina.mueller@suse.com>
- Fix patch IPC-Run-0.89-path.diff (add -p0)
* Mon Aug  8 2022 Tina Müller <timueller+perl@suse.de>
- updated to 20220807.0
  see /usr/share/doc/packages/perl-IPC-Run/Changelog
  20220807.0 Mon Aug 1 2022
  If your applications rely on portability to Windows, see new documentation
  sections "argument-passing rules are program-specific" and "batch files".  This
  release fixes bugs in runs of Windows programs that use standard command line
  parsing rules.  Runs of non-standard programs may require changes.  Notable
  non-standard programs include cmd.exe, cscript.exe, and Cygwin programs.
  - #140 - skip t/pty.t test on NetBSD too
  - Add strict/warnings
  - #142 - Follow Windows argument quoting rules
  - #146 - allow win32_newlines.t to actually run
  - #150 - Make t/pty.t test pass on OpenBSD.
  - #148 - Support Win32 commands having nonstandard command line parsing rules
  - Support executing Win32 batch files.
  - Add IPC::Run::Win32Process, for delivering nonstandard command lines.
  - Fix reporting of Win32::Process::Create() errors.
  - #156 - On Windows, avoid hang when closing read end of pipe.
  - #155 - Ignore known test failure on msys. - t/windows_search_path.t
  - Avoid warning with IPCRUNDEBUG, in Windows spawned children.
  - Use $^X, not 'perl', in tests.
  - Thanks to the New active developer: Noah Misch!
* Thu May  7 2020 Tina Müller <tina.mueller@suse.com>
- Rebase IPC-Run-0.89-path.diff
* Wed May  6 2020 Tina Müller <timueller+perl@suse.de>
  updated to 20200505.0
  see /usr/share/doc/packages/perl-IPC-Run/Changelog
* Thu May 24 2018 coolo@suse.com
- updated to 20180523.0
  see /usr/share/doc/packages/perl-IPC-Run/Changes
  20180523.0 Wed May 23 2018
  - #99 - Fix using fd in child process when it happens to be the same number in
    the child as it was in the parent.
* Fri Apr  6 2018 coolo@suse.com
- updated to 0.99
  see /usr/share/doc/packages/perl-IPC-Run/Changes
  0.99 Fri Mar 30 2018
  - Fixes for windows unit tests so they skip or pass.
    t/autoflush.t
    t/readonly.t
    t/run_stdin-callback-return-array.t
* Fri Mar 30 2018 coolo@suse.com
- updated to 0.98
  see /usr/share/doc/packages/perl-IPC-Run/Changes
  0.98 Thu Mar 29 2018
  - Switch to using $!{EINTR}
  - Honor umask for user/group permissions on a +rw file
  - Remove commented code from RT 50739
  - #63 - Patch for fixing _write on invalid objects
  - #54 - Make slave the controlling terminal so more programs can be called from IPC::Run reliably
  - #53 - Prevent Not a GLOB reference in close_terminal by untieing before close
  - #46 - '&' closing the stdin of the right process.
  - #41 - Do POSIX::_exit not ::exit
  - #40 - Assure child Win32 processes have same priority as parent
  - #38 - Add unit test for passing use of Readonly.pm
  - #39 - Fix GLOB test in IPC::Run::IO->new
  - #86 - Fix for memory leak [rt.cpan.org #57990]
  - MANIFEST was updated. New tests may start shipping now.
  0.97 Mon Mar 26 2018
  - Update meta and POD to point to GitHub issues not RT.
  - Update README with pod changes.
  - Fix variable name in synopsis - [Github #47]
  - Fix t/run.t to work on "perl in space" - [Github #100]
* Wed Mar 28 2018 pmonrealgonzalez@suse.com
- Fixed build on ppc and ppc64 architectures.
- Refreshed spec file with spec-clean.
* Tue Mar 27 2018 coolo@suse.com
- updated to 0.97
  see /usr/share/doc/packages/perl-IPC-Run/Changes
  0.97 Mon Mar 26 2018
  - Update meta and POD to point to GitHub issues not RT.
  - Update README with pod changes.
  - Fix variable name in synopsis - [Github #47]
  - Fix t/run.t to work on "perl in space" - [Github #100]
* Sat Dec 23 2017 avindra@opensuse.org
- updated to 0.96
  - Update bug tracker to https://github.com/toddr/IPC-Run/issues
- includes 0.95
  - Spelling fixes
  - doc fix: full_result returns $?, not $? >> 8
  - Fix check for reaped PID in reap_nb
  - Re-remove unnecessary use of UNIVERSAL
- includes 0.94_02
  - Skip infinity test on perl below 5.8.9
- includes 0.94_01
  - Use q{} and qq{} to fix problems with quotation in cmd.exe
  - sync $VERSION across all files to address kwalitee
  - RT 109243 - Stop side affect of altering flushing of STDOUT
    and STDERR
  - CHILD_HANDLE should be closed with 'Close' to prevent a
    warning.
  - Better timer error message + an additional unit test
  - Catching previously non-detected malformed time strings
  - Let Timer accept all allowable perl numbers
  - allow the OS to choose the ephemeral port to use
  - Don't use version.pm to parse the perl version in Makefile.PL
  - Do not import POSIX into local namespace (it's a memory hog)
  - perltidy
  - require Win32API::File on Windows
- cleanup with spec-cleaner
- rebase IPC-Run-0.89-path.diff
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.94
  see /usr/share/doc/packages/perl-IPC-Run/Changes
  0.94 Sun Dec 14 2014
  - RT 100858 - Update License discrepancies.
  0.93_01 Wed Dec 10 2014
  - Many typo corrections from David Steinbrunner via github
  - RT 20105 - t/pty.t fails on Solaris 10
  0.93 Wed Dec 10 2014
  - RT 100711 - Add aggressive exit to t/signal.t after skip_all to prevent failures.
  - RT 97926 - Fix for run argument with spaces in path
  - skip t/win32_compile.t on Android
  - RT 86133 - TODO failing POD tests for IPC::Run
* Sat Jul 27 2013 coolo@suse.com
- updated to 0.92
  - Tests are good in dev version. Releasing to stable.
  - RT 59775 - Catching a signal during select() can lock up IPC::Run
* Mon Oct 15 2012 coolo@suse.com
- buildrequire explicitly netcfg for the test suite
* Fri Feb 17 2012 vcizek@suse.com
- update to 0.91
  - Tests are good in dev version. Releasing to stable.
  - RT 57277 - Apply suggested 1 line fix for dev release to public.
* Mon Jul 11 2011 vcizek@novell.com
- update to 0.90
  - RT 57277 - Add breaking test. No solution at present.
  - RT 68623 - disable parallel tests on windows
  - RT 43072 - Skip dragonfly platform on t/pty.t (hangs)
  - RT 14078 - run() miscalculates length of UTF-8 strings
  - RT 49693 - security patch for lib/IPC/Run/Win32IO.pm s/INADDR_ANY//
  - RT 38193 - Fix error detection on non-English operating systems
  - Add a blank doc entry for IPC::Run::Win32IO::poll to quiet
    windows pod parser errors
  - RT 57190 - handle PATH environment variable not being defined.
    WILL NOT default to '.' since UNIX would not do this and the
    program has been behaving the UNIX way to date.
- removed authors line from .spec
* Wed Mar 16 2011 cfarrell@novell.com
- license update: GPL+ or Artistic
  See LICENSE - reference is to GPLv1 or later, not GPLv2 or later
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Thu Apr  1 2010 anicka@suse.cz
- update to 0.89
  * Revert extended tests to require "oslo consensus" variables
  * Add IO::Pty to META.yml requirement
  * Missed dangling isa in IPC::Run::Debug
  * Fix retry for read of fh when I get "Resource temporarily
    unavailable."
  * Fix POD indentation in IO.pm
* Tue Mar 30 2010 anicka@suse.cz
- update to 0.87
  * Add doc type fixes - RT 56030 from carnil (Debian)
  * Remove reccommends for AUTHOR only modules
  * add pod_coverage and simplify pod test.
  * document undocumented public subs with TODO and
    best guess as to what they do.
  * Explicity recommend IO::Pty version number 1.08
* Thu Mar 25 2010 anicka@suse.cz
- update to 0.86
  - Add all files to subversion for easier releases
  - bump version on ALL files to 86
  - Remove use UNIVERSAL. - RT 51509
  - fix pod for Win32Helper - RT 51695
  - Better PATHEXT logic bug if cmd_name contains periods - RT 50739
  - Enhance tests for run.t for better diagnostics - RT 47630
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 0.84
  * Add darwin to the list of known-bad platforms
  * Switch from command.com to cmd.exe so we work on 2008 or newer.
* Tue Jan 20 2009 anicka@suse.cz
- update to 0.82
  * Simplfied the Makefile.PL code a little.
  * Upgraded all tests to Test::More
  * Added a $VERSION for all modules
  * Adding some missing POD sections
  * Various other clean ups
* Tue Jun  5 2007 ro@suse.de
- fix one place with wrong interpreter in example script
* Wed Jul 12 2006 anicka@suse.cz
- update to 0.80
  - IPC::Run::IO now retries on certain "temporarily unavailable" errors.
    This should fix several reported issues with t/run.t, test 69.
  - Applied documentation patch from RT.
  - Fixed documentation to work with '<' redirect
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 anicka@suse.cz
- disable run.t as it sometimes fails with
  "Resource temporarily unavailable"
* Mon Aug  1 2005 mjancar@suse.cz
- update to 0.79
* Thu Aug 19 2004 mjancar@suse.cz
- update to 0.78
* Sat Feb 28 2004 ro@suse.de
- fix requirement for /usr/local/bin
* Thu Feb 26 2004 mjancar@suse.cz
- update to 0.77
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Fri Jun 13 2003 mjancar@suse.cz
- initial version 0.75
